@@ -9,7 +9,8 @@ import heapq
 try:
     from .util import AlgoLogger
 except:
-    from util import AlgoLogger
+    from six_pack_trade_algo import *
+    # from util import AlgoLogger
 #
 #
 #       Classes in algos
