@@ -20,13 +20,14 @@ import configparser
 '''
 ##################################################################################
 '''============================================================================'''
-
-from order import *
-from algos import *
-from util import log as log
-from util import DataSource
-from util import Stream
-
+try:
+    from order import *
+    from algos import *
+    from util import log as log
+    from util import DataSource
+    from util import Stream
+except:
+    from six_pack_trade_algo import *
 def main():
     # Load configs according to comand line input
     parser = argparse.ArgumentParser()
