@@ -7,8 +7,7 @@ import pandas as pd
 try:
     from .util import AlgoLogger
 except:
-    from util import AlgoLogger
-
+    from six_pack_trade_algo import *
 
 class OrderManager:
     class Memory:
