@@ -10,7 +10,10 @@ import alpaca_trade_api as tradeapi
 #           Datasource
 #           Stream
 #
-
+try:
+    pass
+except:
+    from six_pack_trade_algo import *
 class AlgoLogger:
     def __init__(self,data_path="", name=""):
         self.to_print = []
